lcwgsus: low-coverage whole-genome sequencing analyses
=======================================

Lcwgsus is a Python package written to perform downstream low-coverage whole-genome sequencing (lcWGS) analyses.


Installation
-------------

Please install lcwgsus with the following command:

`pip install lcwgsus`


Dependencies
------------

Lcwgsus supports Python 3.8+.

Installation requires [numpy](https://numpy.org/), [pandas](https://pandas.pydata.org/), [matplotlib](https://matplotlib.org/), [seaborn](https://seaborn.pydata.org/), [statsmodels](https://statsmodels.org/), and [scipy](https://scipy.org/).

Citation
------------

Lcwgsus is not a published work, so citing the GitHub repo suffices. Please refer to the `CITATION.cff` file.

Development
-----------

See the main site of lcwgsus: https://github.com/Suuuuuuuus/lcwgsus.

Bugs shall be submitted to the [issue tracker](https://github.com/Suuuuuuuus/lcwgsus/issues). Please kindly provide a reproducible example demonstrating the problem.
